diff --git a/cvpcb/readwrite_dlgs.cpp b/cvpcb/readwrite_dlgs.cpp
index 1fc8133851..c23d8a0a6b 100644
--- a/cvpcb/readwrite_dlgs.cpp
+++ b/cvpcb/readwrite_dlgs.cpp
@@ -192,7 +192,7 @@ bool CVPCB_MAINFRAME::ReadNetListAndLinkFiles()
// Check if footprint links were generated before the footprint library table was implemented.
if( hasMissingNicks )
{
- msg = wxT(
+ msg = _(
"Some of the assigned footprints are legacy entries (are missing lib nicknames). "
"Would you like CvPcb to attempt to convert them to the new required FPID format? "
"(If you answer no, then these assignments will be cleared out and you will "
diff --git a/eeschema/dialogs/dialog_choose_component_base.cpp b/eeschema/dialogs/dialog_choose_component_base.cpp
index 2c69e8edfb..3d6f7ad9fd 100644
--- a/eeschema/dialogs/dialog_choose_component_base.cpp
+++ b/eeschema/dialogs/dialog_choose_component_base.cpp
@@ -11,7 +11,7 @@
DIALOG_CHOOSE_COMPONENT_BASE::DIALOG_CHOOSE_COMPONENT_BASE( wxWindow* parent, wxWindowID id, const wxString& title, const wxPoint& pos, const wxSize& size, long style ) : DIALOG_SHIM( parent, id, title, pos, size, style )
{
- this->SetSizeHints( wxSize( 450,100 ), wxDefaultSize );
+ this->SetSizeHints( wxSize( -1,-1 ), wxDefaultSize );
wxBoxSizer* bSizerMain;
bSizerMain = new wxBoxSizer( wxVERTICAL );
@@ -30,7 +30,7 @@ DIALOG_CHOOSE_COMPONENT_BASE::DIALOG_CHOOSE_COMPONENT_BASE( wxWindow* parent, wx
bSizerMain->Add( bSearchSizer, 0, wxEXPAND, 5 );
m_libraryComponentTree = new wxTreeCtrl( this, wxID_ANY, wxDefaultPosition, wxDefaultSize, wxTR_DEFAULT_STYLE|wxTR_HIDE_ROOT );
- m_libraryComponentTree->SetMinSize( wxSize( -1,50 ) );
+ m_libraryComponentTree->SetMinSize( wxSize( 400,200 ) );
bSizerMain->Add( m_libraryComponentTree, 1, wxALL|wxEXPAND, 5 );
@@ -38,12 +38,12 @@ DIALOG_CHOOSE_COMPONENT_BASE::DIALOG_CHOOSE_COMPONENT_BASE( wxWindow* parent, wx
bSizerView = new wxBoxSizer( wxHORIZONTAL );
m_componentView = new wxPanel( this, wxID_ANY, wxDefaultPosition, wxDefaultSize, wxFULL_REPAINT_ON_RESIZE|wxSUNKEN_BORDER );
- m_componentView->SetMinSize( wxSize( 150,150 ) );
+ m_componentView->SetMinSize( wxSize( 200,200 ) );
bSizerView->Add( m_componentView, 4, wxEXPAND | wxALL, 5 );
m_componentDetails = new wxTextCtrl( this, wxID_ANY, wxEmptyString, wxDefaultPosition, wxSize( -1,-1 ), wxTE_MULTILINE );
- m_componentDetails->SetMinSize( wxSize( -1,100 ) );
+ m_componentDetails->SetMinSize( wxSize( 200,200 ) );
bSizerView->Add( m_componentDetails, 3, wxALL|wxEXPAND, 5 );
diff --git a/eeschema/dialogs/dialog_choose_component_base.fbp b/eeschema/dialogs/dialog_choose_component_base.fbp
index 10a46ef4b1..57740013b6 100644
--- a/eeschema/dialogs/dialog_choose_component_base.fbp
+++ b/eeschema/dialogs/dialog_choose_component_base.fbp
@@ -41,10 +41,10 @@
0
wxID_ANY
- 450,100
+ -1,-1
DIALOG_CHOOSE_COMPONENT_BASE
- 450,500
+ 503,500
wxDEFAULT_DIALOG_STYLE|wxRESIZE_BORDER
DIALOG_SHIM; dialog_shim.h
@@ -315,7 +315,7 @@
0
- -1,50
+ 400,200
1
m_libraryComponentTree
1
@@ -426,7 +426,7 @@
0
- 150,150
+ 200,200
1
m_componentView
1
@@ -507,7 +507,7 @@
0
- -1,100
+ 200,200
1
m_componentDetails
1
diff --git a/eeschema/dialogs/dialog_choose_component_base.h b/eeschema/dialogs/dialog_choose_component_base.h
index 3897d5ca76..afcebe61d7 100644
--- a/eeschema/dialogs/dialog_choose_component_base.h
+++ b/eeschema/dialogs/dialog_choose_component_base.h
@@ -61,7 +61,7 @@ class DIALOG_CHOOSE_COMPONENT_BASE : public DIALOG_SHIM
public:
- DIALOG_CHOOSE_COMPONENT_BASE( wxWindow* parent, wxWindowID id = wxID_ANY, const wxString& title = wxEmptyString, const wxPoint& pos = wxDefaultPosition, const wxSize& size = wxSize( 450,500 ), long style = wxDEFAULT_DIALOG_STYLE|wxRESIZE_BORDER );
+ DIALOG_CHOOSE_COMPONENT_BASE( wxWindow* parent, wxWindowID id = wxID_ANY, const wxString& title = wxEmptyString, const wxPoint& pos = wxDefaultPosition, const wxSize& size = wxSize( 503,500 ), long style = wxDEFAULT_DIALOG_STYLE|wxRESIZE_BORDER );
~DIALOG_CHOOSE_COMPONENT_BASE();
};
diff --git a/eeschema/dialogs/dialog_choose_component.cpp b/eeschema/dialogs/dialog_choose_component.cpp
index 21a73bde04..64bf53b182 100644
--- a/eeschema/dialogs/dialog_choose_component.cpp
+++ b/eeschema/dialogs/dialog_choose_component.cpp
@@ -58,9 +58,11 @@ DIALOG_CHOOSE_COMPONENT::DIALOG_CHOOSE_COMPONENT( SCH_BASE_FRAME* aParent, const
m_libraryComponentTree->SetFont( wxFont( font.GetPointSize(),
wxFONTFAMILY_MODERN, wxFONTSTYLE_NORMAL, wxFONTWEIGHT_NORMAL ) );
- // this line fixes an issue on Linux Ubuntu using Unity (dialog not shown),
- // and works fine on all systems
- GetSizer()->Fit( this );
+ // We have to call SetSizeHints to fix the minimal size of the dialog
+ // and its widgets.
+ // this line also fixes an issue on Linux Ubuntu using Unity (dialog not shown).
+ GetSizer()->SetSizeHints( this );
+
Centre();
}